#include <iostream>
#include <cstdio>
#include <string>
#include <cctype>
//#include <string>

using namespace std;

char input[29][7];

const char freespace[][30] = 
{
  "*****  *****     *****  *****",
  "*   *  *   *     *   *  *   *",
  "*   *  *   *  *  *   *  *   *",
  "*****  *****     *****  *****",
  "*   *  *   *  *  *   *  *   *",
  "*   *  *   *     *   *  *   *",
  "*****  *****     *****  *****"
};

struct xy
{
  const int x, y;
  const char ch;
  const bool end;
  xy(int x, int y, char ch) : x(x), y(y), ch(ch), end(false) {}
  xy() : x(0), y(0), ch(0), end(true) {}
};

const xy segments[][8] = {
/* 00 */  {xy()},
/* 01 */  {xy(0,0,'+'), xy(1,0,'-'), xy(2,0,'-'), xy(3,0,'-'), xy(4,0,'+'), xy()},
/* 02 */  {xy(0,0,'+'), xy(0,1,'|'), xy(0,2,'|'), xy(0,3,'+'), xy()},
/* 03 */  {xy(4,0,'+'), xy(4,1,'|'), xy(4,2,'|'), xy(4,3,'+'), xy()},
/* 04 */  {xy(0,3,'+'), xy(1,3,'-'), xy(2,3,'-'), xy(3,3,'-'), xy(4,3,'+'), xy()},
/* 05 */  {xy(0,3,'+'), xy(0,4,'|'), xy(0,5,'|'), xy(0,6,'+'), xy()},
/* 06 */  {xy(4,3,'+'), xy(4,4,'|'), xy(4,5,'|'), xy(4,6,'+'), xy()},
/* 07 */  {xy(0,6,'+'), xy(1,6,'-'), xy(2,6,'-'), xy(3,6,'-'), xy(4,6,'+'), xy()},
/* 08 */  {xy()},
/* 09 */  {xy()},
/* 10 */  {xy()},
/* 11 */  {xy(1,0,' '), xy(2,0,' '), xy(3,0,' '), xy()},
/* 12 */  {xy(0,1,' '), xy(0,2,' '), xy()},
/* 13 */  {xy(4,1,' '), xy(4,2,' '), xy()},
/* 14 */  {xy(1,3,' '), xy(2,3,' '), xy(3,3,' '), xy()},
/* 15 */  {xy(0,4,' '), xy(0,5,' '), xy()},
/* 16 */  {xy(4,4,' '), xy(4,5,' '), xy()},
/* 17 */  {xy(1,6,' '), xy(2,6,' '), xy(3,6,' '), xy()},
};

inline bool shouldBeFree(int x, int y)
{
  return freespace[y][x] == ' ';
}

inline char in(int x, int y)
{
  return input[x][y];
}



bool checkFreeSpace()
{
  /*
  for(int x = 29; x--;)
    for(int y = 7; y--;)
      if(shouldBeFree(x, y))
      {
	const char inputChar = in(x,y);
	if((inputChar != '.') || (inputChar != ' '))
	  return false;
      }
      */
  return true;
  
}


const int digitSegments[][10] = {
  {1,2,3,5,6,7, 14, 0},
  {3,6, 11,12,14,15,17, 0},
  {1,3,4,5,7, 12,16, 0},
  {1,3,4,6,7, 12,15, 0},
  {2,3,4,6, 11,15,17, 0},
  {1,2,4,6,7, 13,15, 0},
  {1,2,4,5,6,7, 13, 0},
  {1,3,6, 12,14,15,17, 0},
  {1,2,3,4,5,6,7, 0},
  {1,2,3,4,6,7, 15, 0}
};


bool matchSegment(int segmentIndex, int shiftX)
{
  const xy * segment = segments[segmentIndex];
  for(int i = 0; !segment[i].end; i++)
  {
    const int x = segment[i].x + shiftX;
    const int y = segment[i].y;
    const char requiredChar = segment[i].ch;
    const char inChar = in(x, y);
    if((inChar != '.') && (inChar != requiredChar))
      return false;
  }
  
  return true;
}

int matchDigit(int shift, int maximum, int minimum = 0)
{
  bool validDigit[10] = {true, true, true, true, true, true, true, true, true, true};
  
  for(int digit = 0; digit <= maximum; digit++)
  {
    const int * segments = digitSegments[digit];
    for(int i = minimum; segments[i] > 0; i++)
    {
      if(!matchSegment(segments[i], shift))
      {
	validDigit[digit] = false;
	break;
      }
    }
  }
  
  int validDigits = 0;
  int lastValidDigit = -1;
  for(int i = minimum; i <= maximum; i++)
    if(validDigit[i])
    {
      validDigits++;
      lastValidDigit = i;
    }
  return (validDigits == 1) ? lastValidDigit : -1;
}

bool matchDots()
{
  return ((in(14,2) == 'o') || (in(14,2) == '.')) && (in(14,4) == 'o' || in(14,4) == '.');
}

inline void check()
{
  if(checkFreeSpace())
  {
    const int digit2b = matchDigit(0, 9, 4);
    const int digit1 = matchDigit(0, (digit2b == -1) ? 2 : 1);
    if(digit1 < 0)
    {
      cout << "ambiguous" << endl;
      return;
    }
    const int digit2 = matchDigit(7, (digit1 != 2 ? 9 : 3));
    const int digit3 = matchDigit(17, 5);
    const int digit4 = matchDigit(24, 9);
    /*
    if(digit2 < 0 || digit3 < 0 || digit4 < 0)
    {
      cout << "ambiguous" << endl;
      return;
    }
    */
    cout << digit1 << digit2 << ':' << digit3 << digit4 << endl;
    return;
  }
  else
  {
    cout << "ambiguous" << endl;
    return;
  }
}


int main(){
  string line;
  while(getline(cin, line), line != string("end"))
  {
    for(int y = 0; y < 7; y++)
    {
      for(int x = 29; x--;)
      {
	input[x][y] = line[x];
      }
      getline(cin, line);
    }
    getline(cin, line);
    check();
  }
  cout << "end" << endl;
  return 0;
}
